==> lori_sdk-0.0.1.tar.gz: lib/data/models/cart/cartItem.dart <==
import 'dart:core';

import 'package:json_annotation/json_annotation.dart';
import 'package:lori_sdk/data/models/product/product.dart';
part 'cartItem.g.dart';

const CART_ITEM_CURRENT_VERSION = 2;

@JsonSerializable()
class CartItem {

  CartItem();

  /// The CartItem unique identifier
  String id;

  /// The sku related to this item
  Sku sku;

  /// The quantity requested by the user for this item
  int quantity;

  /// The quantity available on the seller for this item
  int quantityAvailable;

  /// The quantity separated (a.k.a. that can be bought) for this item
  int quantitySeparated;

  @Deprecated("Please use subTotalAmount instead")
  double price;
  @Deprecated("Please use subTotalSeparatedAmount instead")
  double priceSeparated;

  /// The price of each unit of this item, without any modifiers
  double unitPrice;


  /// The discount price applied to this item (if any)
  ///
  /// The discount price will ALWAYS be applied to ONLY ONE unit of the item
  double discountPrice;


  /// The subtotal price of this item, without any modifiers
  ///
  /// (a.k.a. unitPrice * quantity)
  double subTotalAmount;

  /// The subtotal price of this item, considering only the SEPARATED ITEMS and without any modifiers
  ///
  /// (a.k.a. unitPrice * quantitySeparated
  double subTotalSeparatedAmount;


  /// The total price of this item, applying the modifiers
  ///
  /// (a.k.a. subTotalAmount - discountPrice)
  double totalAmount;

  /// The total price of this item, considering only the SEPARATED ITEMS and applying the modifiers
  ///
  /// (a.k.a. subTotalSeparatedAmount - discountPrice)
  double totalSeparatedAmount;

  void migrateToCurrentVersion() {
    if (CART_ITEM_CURRENT_VERSION == 2) {
      //Create the new price values from "price" and "priceSeparated"
      this.unitPrice = this.price / this.quantity;
      this.discountPrice = 0.0;
      this.subTotalAmount = this.price;
      this.subTotalSeparatedAmount = this.priceSeparated;
      this.totalAmount = this.price;
      this.totalSeparatedAmount = this.priceSeparated;
    }
  }


  factory CartItem.fromJson(Map<String, dynamic> json) => _$CartItemFromJson(json);
  Map<String, dynamic> toJson() => _$CartItemToJson(this);
}

==> lori_sdk-0.0.8.tar.gz: lib/data/models/cart/cartItem.dart <==
import 'dart:core';

import 'package:json_annotation/json_annotation.dart';
import 'package:lori_sdk/data/models/product/product.dart';

part 'cartItem.g.dart';

const CART_ITEM_CURRENT_VERSION = 2;

@JsonSerializable()
class CartItem {
  CartItem();

  /// The CartItem unique identifier
  String id;

  /// The sku related to this item
  Sku sku;

  /// The quantity requested by the user for this item
  int quantity;

  /// The quantity available on the seller for this item
  int quantityAvailable;

  /// The quantity separated (a.k.a. that can be bought) for this item
  int quantitySeparated;

  @Deprecated("Please use subTotalAmount instead")
  double price;
  @Deprecated("Please use subTotalSeparatedAmount instead")
  double priceSeparated;

  /// The price of each unit of this item, without any modifiers
  double unitPrice;

  /// The discount price applied to this item (if any)
  ///
  /// The discount price will ALWAYS be applied to ONLY ONE unit of the item
  double discountPrice;

  /// The subtotal price of this item, without any modifiers
  ///
  /// (a.k.a. unitPrice * quantity)
  double subTotalAmount;

  /// The subtotal price of this item, considering only the SEPARATED ITEMS and without any modifiers
  ///
  /// (a.k.a. unitPrice * quantitySeparated
  double subTotalSeparatedAmount;

  /// The total price of this item, applying the modifiers
  ///
  /// (a.k.a. subTotalAmount - discountPrice)
  double totalAmount;

  /// The total price of this item, considering only the SEPARATED ITEMS and applying the modifiers
  ///
  /// (a.k.a. subTotalSeparatedAmount - discountPrice)
  double totalSeparatedAmount;

  void migrateToCurrentVersion() {
    if (CART_ITEM_CURRENT_VERSION == 2) {
      //Create the new price values from "price" and "priceSeparated"
      this.unitPrice = this.price / this.quantity;
      this.discountPrice = 0.0;
      this.subTotalAmount = this.price;
      this.subTotalSeparatedAmount = this.priceSeparated;
      this.totalAmount = this.price;
      this.totalSeparatedAmount = this.priceSeparated;
    }
  }

  factory CartItem.fromJson(Map<String, dynamic> json) =>
      _$CartItemFromJson(json);

  Map<String, dynamic> toJson() => _$CartItemToJson(this);
}
